#
# spec file for package wsjt
#
# Copyright (c) 2017 Walter Fey DL8FCL
#
# This file is under MIT license

Name:		wsjt
Version:        10.0.r6005
Release:        lp156.4.1
License:        GPL-2.0
Summary:	Weak-signal amateur radio communications
URL:            http://physics.princeton.edu/pulsar/K1JT
Group:          Productivity/Hamradio/Other
Source0:	%{name}-%{version}.tar.xz
Source1:        readme_opensuse
Source2:        wsjt.png
Patch0:         astro.py.diff
Patch1:         Makefile.in.diff
Patch2:         wsjt_python3.diff
BuildRoot:	%{_tmppath}/%{name}-%{version}-build

BuildRequires:  alsa-devel
BuildRequires:  f2c
BuildRequires:  fftw3-devel
BuildRequires:  gcc-fortran
BuildRequires:  libsamplerate-devel
BuildRequires:  portaudio-devel
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-numpy-devel
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  update-desktop-files

Requires:	python3
Requires:       python3-tk
Requires:	python3-numpy

%if 0%{suse_version} != 1315
Requires:       python3-Pillow-tk
%endif

%if 0%{suse_version} == 1315
Requires:       python3-Pillow
%endif

%ifarch == x86_64
Requires:       libgfortran3-32bit
%endif

%description
WSJT is a computer program designed to facilitate Amateur Radio
communication under extreme weak-signal conditions.  Three very
different coding and modulation methods are provided: one for
communication by "meteor scatter" techniques on the VHF bands; one for
meteor and ionospheric scatter, primarily on the 6 meter band; and one
for the very challenging EME (Earth-Moon-Earth) path.

 Authors:  
 --------  
     K1JT    -   Joe Taylor

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

# coding definition is missing in the file wsjt.py.
# Direct editing the file is easier than patching
sed -i '/env python/ a\
# -*- coding: latin-1 -*-
' wsjt.py

sed -i 's|#!/usr/bin/env python|#!/usr/bin/python3|' wsjt.py


%build 
%configure \
    --with-portaudio-include-dir=%{_includedir} \
    --with-portaudio-lib-dir=%{_libdir}
make

%install
strip --strip-unneeded WsjtMod/Audio.so

install -D wsjt %{buildroot}%{_bindir}/wsjt
install wsjt.py %{buildroot}%{_bindir}
install -D -m 644 CALL3.TXT %{buildroot}%{_datadir}/%{name}/CALL3.TXT
install -m 644 wsjtrc dmet_*.dat %{buildroot}%{_datadir}/%{name}
install -d %{buildroot}/%{python3_sitearch}/WsjtMod
install -m 644 WsjtMod/*.py WsjtMod/*.so %{buildroot}/%{python3_sitearch}/WsjtMod
install -m 644 Pmw.py %{buildroot}/%{python3_sitearch}
install -m 644 PmwBlt.py %{buildroot}/%{python3_sitearch}
install -m 644 PmwColor.py %{buildroot}/%{python3_sitearch}
install -D -m 644 LICENSE.TXT  %{buildroot}/%{_docdir}/%{name}/LICENSE.TXT
install -m 644 "%{SOURCE1}" %{buildroot}/%{_docdir}/%{name}

%suse_update_desktop_file -c wsjt Wsjt "Weak-signal communications" wsjt wsjt "Network;HamRadio"

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
%{python3_sitearch}/*
%{_datadir}/pixmaps/wsjt.png
%{_datadir}/%{name}
%{_datadir}/applications/wsjt.desktop
%{_docdir}/%{name}

%changelog
* Sun Mar  3 2019 Martin Hauke <mardnh@gmx.de>
- Fix python-build depedencies
* Tue Nov 10 2015 dl8fcl@darc.de
- update to version 10.0 r6005
  new mode fsk315 and other improvements
  Fixed ISCAT auto configure issue when updating report
* Sun Jun 28 2015 dl8fcl@darc.de
- update to version 10.0 r5634
  Further improvements to ISCAT decoder
* Wed May 27 2015 dl8fcl@darc.de
- update to version 10.0 r5422
  version number corrected
* Fri May 22 2015 dl8fcl@darc.de
- update to version 10.0 r5401
  just to offer the latest version, changes not importened for LINUX
* Tue Apr 21 2015 dl8fcl@darc.de
- update to version 10.0 r5247
  Fixed bug where AZEL.dat would no longer update if client program
  was not polite in opening it.
* Sun Mar 29 2015 dl8fcl@darc.de
- update to version 10.0 r5126
  Protect use of index of array iwave0()
* Sat Mar 14 2015 dl8fcl@darc.de
- update to version 10.0 r5046
  Repair the broken command "Delete all *.wav files..."
* Tue Mar 10 2015 dl8fcl@darc.de
- update to version 10.0 r5022
  minor enhancements
* Sat Sep 27 2014 dl8fcl@darc.de
- update to version 10.0 r4336
* Sun Jan 19 2014 dl8fcl@darc.de
- update to version 9.7.r3639
  Make JTMS mode visible, remove Diana mode entirely
  Add WSJT 9.7 Supplement to User's Guide.
  Updates to manual
* Wed Jan  8 2014 dl8fcl@darc.de
- update to version 9.5.r3619
  Use usleep.c rather than cutil.c - r3604
  Allow up to 100 audio devices
* Fri May 17 2013 dl8fcl@darc.de
- update to version 9.5.r3281, Send shorthand
  messages only if remaining characters are all blank
* Tue Apr 30 2013 dl8fcl@darc.de
- update to version 9.5.r3122 - Fix pack/unpack bugs
* Sun Mar 24 2013 dl8fcl@darc.de
- update to version 9.5.r3072 - bugfix release
* Tue Mar  5 2013 dl8fcl@darc.de
- update to version 9.5.r3036
  Further improvement of decoding speed and
  bug fixes.
* Sat Feb  2 2013 dl8fcl@darc.de
- update to version 9.4.r2995
  Improve decoding speed
  message averaging and deep search in JT4 mode
* Wed Jan 23 2013 dl8fcl@darc.de
- update to version 9.3.r2965
  code is migrating towards *.f90
* Sun Jan 20 2013 dl8fcl@darc.de
- update to version 9.3.r2956
  crash when decoding FSK441 fixed
* Thu Jan  3 2013 dl8fcl@darc.de
- step back to 9.1.r2434. Newer versions crash while
  decoding FSK441
* Thu Jul 14 2011 dl8fcl@darc.de
- update to version 9.1.r2436
* Sun May 22 2011 dl8fcl@darc.de
- update to version 9.1.r2434
* Sun Dec  5 2010 dl8fcl@darc.de
- update to version 9.02.svn.r2273
* Sun Sep  5 2010 dl8fcl@darc.de
- update to version 7.07.svn.r2130
* Fri Jul 16 2010 dl8fcl@darc.de
- fix for new python-numpy
* Tue Jul  6 2010 dl8fcl@darc.de
- update to svn.r1949
* Mon Mar  8 2010 dl8fcl@darc.de
- update to svn.r1827
* Wed Jan 27 2010 dl8fcl@darc.de
- update to svn.r1783
* Wed Dec  2 2009 dl8fcl@darc.de
- import into buildservice
